==> nextcloud-23.0.9.tgz: nextcloud/apps/theming/l10n/ka_GE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "პრევიუს ჩატვირთვა…",
    "Admin" : "ადმინისტრაცია",
    "Saved" : "შენახულია",
    "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "Name cannot be empty" : "სახელი ვერ იქნება ცარიელი",
    "The given name is too long" : "მოცემული სახელი ძალიან გრძელია",
    "The given web address is too long" : "მოცემული ვებ-მისამართი ძალიან გრძელია",
    "The given slogan is too long" : "მოცემული ლოზუნგი ძალიან გრძელია",
    "The given color is invalid" : "მოცემული ფერი არასწორია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "No file uploaded" : "ფაილი არ იქნა ატვირთული",
    "Theming" : "ვიზუალური თემები",
    "Dark theme" : "მუქი თემა",
    "Enable dark theme" : "მუქი თემის გააქტიურება",
    "Dyslexia font" : "შრიფტი Dyslexia ",
    "Enable dyslexia font" : "ჩართე დისლექსიის შრიფტი",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic-ი უფასო გარნიტურა/შრიფტია, რომელიც შექმნილია დისლექსიით გამოწვეული წაკითხვის ზოგიერთი პრობლემის აღმოსაფხვრელად.",
    "High contrast mode" : "მაღალ-კონტრასტული რეჟიმი",
    "Enable high contrast mode" : "ჩართე მაღალ-კონტრასტული რეჟიმი",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "მაღალ-კონტრასტული რეჟიმი თქვენი ნავიგაციის გასამარტივებლად. ვიზუალური ხარისხი შემცირდება, თუმცა, გაიზრდება სიმკვეთრე. ",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "უნივერსალური წვდომა ჩვენთვის ძალზედ მნივნელოვანია. ჩვენ მივსდევთ ინტერნეტის სტანდარტებს და ვცდილობთ გავხადოთ ყველაფერი ხელმისაწვდომი მაუსის და დამხამრე პროგრამული უზრუნველყოფის გარეშე, ისეთის როგორიცაა ეკრანის წამკითხველი. ჩვენი მიზანია შესაბამისობაში ვიყოთ {guidelines}ქსელის შიგთავსის ხელმისაწვდომობის სახელმძღვანელო{linkend}  2.1-თან AA დონეზე, ხოლო  მაღალ-კონტრასტული თემით AAA დონეზეც კი.",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "ვიზუალური თემები საშუალებას გაძლევთ თქვენს ინსტანციას და მხარდაჭერილ კლიენტებს მარტივად გაუწიოთ გამოსახულებას პერსონალიზაცია. ეს გამოჩნდება ყველა მომხმარებელთან.",
    "Name" : "სახელი",
    "Reset to default" : "საწყის მდგომარეობაში დაბრუნება",
    "Slogan" : "ლოზუნგი",
    "Color" : "ფერი",
    "Logo" : "ლოგო",
    "Upload new logo" : "ახალი ლოგოს ატვირთვა",
    "Login image" : "ლოგინის სურათი",
    "Upload new login background" : "ლოგინის ახალი ფონის ატვირთვა",
    "Remove background image" : "ფონური სურათის მოშორება",
    "Advanced options" : "დამატებითი ოპციონები",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "SVG სურთების მხარდაჭერის მქონე Imagemagick PHP გაფართოების დაყენება ფავიკონებს  ატვირთული ლოგოსა და ფერის მიხევით დააგენერირებს ავტომატურად."
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/theming/l10n/ka_GE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "პრევიუს ჩატვირთვა…",
    "Admin" : "ადმინისტრაცია",
    "Saved" : "შენახულია",
    "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "Name cannot be empty" : "სახელი ვერ იქნება ცარიელი",
    "The given name is too long" : "მოცემული სახელი ძალიან გრძელია",
    "The given web address is too long" : "მოცემული ვებ-მისამართი ძალიან გრძელია",
    "The given slogan is too long" : "მოცემული ლოზუნგი ძალიან გრძელია",
    "The given color is invalid" : "მოცემული ფერი არასწორია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "No file uploaded" : "ფაილი არ იქნა ატვირთული",
    "Theming" : "ვიზუალური თემები",
    "Dark theme" : "მუქი თემა",
    "Enable dark theme" : "მუქი თემის გააქტიურება",
    "Dyslexia font" : "შრიფტი Dyslexia ",
    "Enable dyslexia font" : "ჩართე დისლექსიის შრიფტი",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic-ი უფასო გარნიტურა/შრიფტია, რომელიც შექმნილია დისლექსიით გამოწვეული წაკითხვის ზოგიერთი პრობლემის აღმოსაფხვრელად.",
    "High contrast mode" : "მაღალ-კონტრასტული რეჟიმი",
    "Enable high contrast mode" : "ჩართე მაღალ-კონტრასტული რეჟიმი",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "მაღალ-კონტრასტული რეჟიმი თქვენი ნავიგაციის გასამარტივებლად. ვიზუალური ხარისხი შემცირდება, თუმცა, გაიზრდება სიმკვეთრე. ",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "უნივერსალური წვდომა ჩვენთვის ძალზედ მნივნელოვანია. ჩვენ მივსდევთ ინტერნეტის სტანდარტებს და ვცდილობთ გავხადოთ ყველაფერი ხელმისაწვდომი მაუსის და დამხამრე პროგრამული უზრუნველყოფის გარეშე, ისეთის როგორიცაა ეკრანის წამკითხველი. ჩვენი მიზანია შესაბამისობაში ვიყოთ {guidelines}ქსელის შიგთავსის ხელმისაწვდომობის სახელმძღვანელო{linkend}  2.1-თან AA დონეზე, ხოლო  მაღალ-კონტრასტული თემით AAA დონეზეც კი.",
    "Pick from Files" : "აირჩიე ფაილებიდან",
    "Plain background" : "ცარიელი ფონი",
    "Insert from {productName}" : "შეავსეთ {productName}-დან",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "ვიზუალური თემები საშუალებას გაძლევთ თქვენს ინსტანციას და მხარდაჭერილ კლიენტებს მარტივად გაუწიოთ გამოსახულებას პერსონალიზაცია. ეს გამოჩნდება ყველა მომხმარებელთან.",
    "Name" : "სახელი",
    "Reset to default" : "საწყის მდგომარეობაში დაბრუნება",
    "Slogan" : "ლოზუნგი",
    "Color" : "ფერი",
    "Logo" : "ლოგო",
    "Upload new logo" : "ახალი ლოგოს ატვირთვა",
    "Login image" : "ლოგინის სურათი",
    "Upload new login background" : "ლოგინის ახალი ფონის ატვირთვა",
    "Remove background image" : "ფონური სურათის მოშორება",
    "Advanced options" : "დამატებითი ოპციონები",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "SVG სურთების მხარდაჭერის მქონე Imagemagick PHP გაფართოების დაყენება ფავიკონებს  ატვირთული ლოგოსა და ფერის მიხევით დააგენერირებს ავტომატურად."
},
"nplurals=2; plural=(n!=1);");
